Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(917)

Unified Diff: runtime/vm/object.h

Issue 10885039: Deoptimization can occur at Dart calls (includes native calls to C) but not at runtime calls. This … (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/native_entry.h ('k') | runtime/vm/object.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/object.h
===================================================================
--- runtime/vm/object.h (revision 11621)
+++ runtime/vm/object.h (working copy)
@@ -2261,12 +2261,13 @@
public:
enum Kind {
- kDeopt = 0, // Deoptimization continuation point.
- kDeoptIndex, // Index into deopt info array.
- kPatchCode, // Buffer for patching code entry.
- kIcCall, // IC call.
- kFuncCall, // Call to known target, e.g. static call, closure call.
- kReturn, // Return from function.
+ kDeoptBefore = 0, // Deoptimization continuation point before instruction.
+ kDeoptAfter, // Deoptimization continuation point after instruction.
+ kDeoptIndex, // Index into deopt info array.
+ kPatchCode, // Buffer for patching code entry.
+ kIcCall, // IC call.
+ kFuncCall, // Call to known target, e.g. static call, closure call.
+ kReturn, // Return from function.
kOther
};
@@ -2641,7 +2642,8 @@
// Find pc of patch code buffer. Return 0 if not found.
uword GetPatchCodePc() const;
- uword GetDeoptPcAtDeoptId(intptr_t deopt_id) const;
+ uword GetDeoptBeforePcAtDeoptId(intptr_t deopt_id) const;
+ uword GetDeoptAfterPcAtDeoptId(intptr_t deopt_id) const;
// Returns true if there is an object in the code between 'start_offset'
// (inclusive) and 'end_offset' (exclusive).
@@ -2689,6 +2691,8 @@
*PointerOffsetAddrAt(index) = offset_in_instructions;
}
+ uword GetPcForDeoptId(intptr_t deopt_id, PcDescriptors::Kind kind) const;
+
// New is a private method as RawInstruction and RawCode objects should
// only be created using the Code::FinalizeCode method. This method creates
// the RawInstruction and RawCode objects, sets up the pointer offsets
« no previous file with comments | « runtime/vm/native_entry.h ('k') | runtime/vm/object.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698